@@ -3,7 +3,7 @@
 #include "LocationModule.h"
 #include <QTimer>
 float speed=0;
-extern SpeedoMeter *pW;
+extern Speedo *pW;
 float trip=0;
 float total=0;
 int appClose=0;
@@ -12,17 +12,17 @@ float seconds=0;
 //LocationThread l;
 
 
-SpeedoMeter::SpeedoMeter(QWidget *parent) :
+Speedo::Speedo(QWidget *parent) :
     QMainWindow(parent),
-    ui(new Ui::SpeedoMeter)
+    ui(new Ui::Speedo)
 {
     ui->setupUi(this);
     unit = 0;
     //ui->lcdNumber->display(speed);
     //ui->lcdNumber->setBaseSize(32,32);
 
-    ui->lcdNumber_3->setDigitCount(7);
-    ui->lcdNumber_2->setDigitCount(7);
+    //ui->lcdNumber_3->setDigitCount(7);
+    //ui->lcdNumber_2->setDigitCount(7);
     ui->lcdNumber->setDigitCount(7);
     ui->lcdNumber_4->setDigitCount(10);
 
@@ -42,6 +42,7 @@ SpeedoMeter::SpeedoMeter(QWidget *parent) :
     }
     hour=min=sec=tensofsec=0;
     started=0;paused=0;
+    display=0; // set default to speed display
     QTimer *t=new QTimer(this);
     connect(t,SIGNAL(timeout()),this,SLOT(updateLocation()) );
     t->start(1000);
@@ -51,7 +52,7 @@ SpeedoMeter::SpeedoMeter(QWidget *parent) :
 
 }
 
-SpeedoMeter::~SpeedoMeter()
+Speedo::~Speedo()
 {
     delete ui;
     FILE *fp=fopen("/home/user/.speedrec","w");
@@ -63,7 +64,7 @@ SpeedoMeter::~SpeedoMeter()
     stopLocation();
 }
 
-void SpeedoMeter::changeEvent(QEvent *e)
+void Speedo::changeEvent(QEvent *e)
 {
     QMainWindow::changeEvent(e);
     switch (e->type()) {
@@ -75,15 +76,15 @@ void SpeedoMeter::changeEvent(QEvent *e)
     }
 }
 
-void SpeedoMeter::on_pushButton_clicked()
+void Speedo::on_pushButton_clicked()
 {
     trip=0;
 }
-void SpeedoMeter::start_gps()
+void Speedo::start_gps()
 {
    initLocation();
 }
-void SpeedoMeter::updateLocation()
+void Speedo::updateLocation()
 {
     speed = locationModuleVar_Speed;
     //speed++;
@@ -101,11 +102,13 @@ void SpeedoMeter::updateLocation()
     float d_trip;
     float d_total;
     float d_average;
+    QString sUnit;
     if(unit==0)
     {
-        ui->label->setText("km/h");
-        ui->label_2->setText("km (trip)");
-        ui->label_3->setText("km");
+        sUnit="km";
+        //ui->label->setText("km/h");
+        //ui->label_2->setText("km (trip)");
+        //ui->label_3->setText("km");
         ui->label_5->setText("km/h");
         d_speed=(int)speed;
         d_trip = trip;
@@ -115,39 +118,54 @@ void SpeedoMeter::updateLocation()
     }
     else
     {
+        sUnit="mi";
         d_speed =(int)(speed/1.609);
         d_trip = trip/1.609;
         d_total=total/1.609;
         d_average=average_speed/1.609;
-        ui->label->setText("mph");
-        ui->label_2->setText("mi (trip)");
-        ui->label_3->setText("mi");
+        //ui->label->setText("mph");
+        //ui->label_2->setText("mi (trip)");
+        //ui->label_3->setText("mi");
         ui->label_5->setText("mph");
 
     }
 
     char buf[20];
-    ui->lcdNumber->display(d_speed);
-    sprintf(buf,"%.2f",d_trip);
+    if(display==0)
+    {
+        ui->lcdNumber->display(d_speed);
+        QString text;
+        text=sUnit+"/h";
+        ui->label->setText(text);
+    }
+    else if(display==1)
+    {
+        sprintf(buf,"%.2f",d_trip);
     // replace , with . for QLcdNumber
-    for(int i=0;i<strlen(buf);i++){
+    for(unsigned int i=0;i<strlen(buf);i++){
         if(buf[i]==',')buf[i]='.';}
-    ui->lcdNumber_2->display(QString(buf));
+    QString text=sUnit+" (trip)";
+    ui->lcdNumber->display(QString(buf));
+    ui->label->setText(text);
+    }
+    else
+    {
     sprintf(buf,"%.2f",d_total);
     // replace , with . for QLcdNumber
-    for(int i=0;i<strlen(buf);i++){
+    for(unsigned int i=0;i<strlen(buf);i++){
         if(buf[i]==',')buf[i]='.';}
-    ui->lcdNumber_3->display(QString(buf));
-
+    ui->lcdNumber->display(QString(buf));
+    ui->label->setText(sUnit);
+    }
     sprintf(buf,"%.2f",d_average);
     // replace , with . for QLcdNumber
-    for(int i=0;i<strlen(buf);i++){
+    for(unsigned int i=0;i<strlen(buf);i++){
         if(buf[i]==',')buf[i]='.';}
     ui->lcdNumber_5->display(QString(buf));
 
 }
 
-void SpeedoMeter::updateTime()
+void Speedo::updateTime()
 {
 
 char buf[80];char h[3],m[3],s[3];
@@ -175,18 +193,18 @@ ui->lcdNumber_4->display(QString(buf));
 
 }
 
-void SpeedoMeter::on_pushButton_2_clicked()
+void Speedo::on_pushButton_2_clicked()
 {
     unit = 1-unit; // 0 km, 1-miles
 }
 
-void SpeedoMeter::on_startTimeButton_clicked()
+void Speedo::on_startTimeButton_clicked()
 {
     started=1;paused=0;
 
 }
 
-void SpeedoMeter::on_pauseTimeButton_clicked()
+void Speedo::on_pauseTimeButton_clicked()
 {
     if(paused){
         hour=min=sec=tensofsec=seconds=0;started=0;average_speed=0;
@@ -194,3 +212,10 @@ void SpeedoMeter::on_pauseTimeButton_clicked()
     paused=1-paused;
 
 }
+
+void Speedo::on_pushButton_3_clicked()
+{
+    display++;
+    if(display>2)
+        display=0;
+}
