@@ -4,24 +4,26 @@
 #include <QMainWindow>
 #include <QThread>
 namespace Ui {
-    class SpeedoMeter;
+    class Speedo;
 }
 
-class SpeedoMeter : public QMainWindow {
+class Speedo : public QMainWindow {
     Q_OBJECT
 public:
-    SpeedoMeter(QWidget *parent = 0);
-    ~SpeedoMeter();
-    Ui::SpeedoMeter *ui;
+    Speedo(QWidget *parent = 0);
+    ~Speedo();
+    Ui::Speedo *ui;
     int unit;
     int hour,min,sec,tensofsec;
     int started,paused;
+    int display; // 0 speed, 1-trip, 2-total
 
 protected:
     void changeEvent(QEvent *e);
 
 
 private slots:
+    void on_pushButton_3_clicked();
     void on_pauseTimeButton_clicked();
     void on_startTimeButton_clicked();
     void on_pushButton_2_clicked();
